import { ProjectGraphExternalNode, ProjectGraphProjectNode } from '../../../../config/project-graph';
/**
 * The key is a combination of the package name and the workspace relative directory
 * containing the file importing it e.g. `lodash__packages/my-lib`, the value is the
 * resolved external node name from the project graph.
 */
type NpmResolutionCache = Map<string, string>;
export declare function isBuiltinModuleImport(importExpr: string): boolean;
export declare class TargetProjectLocator {
    private readonly nodes;
    readonly externalNodes: Record<string, ProjectGraphExternalNode>;
    private readonly npmResolutionCache;
    private projectRootMappings;
    private npmProjects;
    private tsConfig;
    private paths;
    private typescriptResolutionCache;
    constructor(nodes: Record<string, ProjectGraphProjectNode>, externalNodes?: Record<string, ProjectGraphExternalNode>, npmResolutionCache?: NpmResolutionCache);
    /**
     * Resolve any workspace or external project that matches the given import expression,
     * originating from the given filePath.
     *
     * @param importExpr
     * @param filePath
     */
    findProjectFromImport(importExpr: string, filePath: string): string;
    /**
     * Resolve any external project that matches the given import expression,
     * relative to the given file path.
     *
     * @param importExpr
     * @param projectRoot
     */
    findNpmProjectFromImport(importExpr: string, fromFilePath: string): string | undefined;
    /**
     * Return file paths matching the import relative to the repo root
     * @param normalizedImportExpr
     * @returns
     */
    findPaths(normalizedImportExpr: string): string[] | undefined;
    private resolveImportWithTypescript;
    private resolveImportWithRequire;
    private findProjectOfResolvedModule;
    private getAbsolutePath;
    private getRootTsConfig;
    private findMatchingProjectFiles;
}
export {};
