"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findExternalPackageJsonPath = void 0;
const node_fs_1 = require("node:fs");
const node_path_1 = require("node:path");
/**
 * In many cases the package.json will be directly resolvable, so we try that first.
 * If, however, package exports are used and the package.json is not defined, we will
 * need to resolve the main entry point of the package and traverse upwards to find the
 * package.json.
 *
 * NOTE: Unit testing this code is currently impractical as it is not possible to mock
 * require.resolve in jest https://github.com/jestjs/jest/issues/9543
 */
function findExternalPackageJsonPath(packageName, relativeToDir) {
    try {
        return require.resolve((0, node_path_1.join)(packageName, 'package.json'), {
            paths: [relativeToDir],
        });
    }
    catch {
        try {
            // Resolve the main entry point of the package
            const mainPath = require.resolve(packageName, {
                paths: [relativeToDir],
            });
            let dir = (0, node_path_1.dirname)(mainPath);
            while (dir !== (0, node_path_1.parse)(dir).root) {
                const packageJsonPath = (0, node_path_1.join)(dir, 'package.json');
                if ((0, node_fs_1.existsSync)(packageJsonPath)) {
                    return packageJsonPath;
                }
                dir = (0, node_path_1.dirname)(dir);
            }
            throw new Error(`Could not find package.json for ${packageName}`);
        }
        catch {
            return null;
        }
    }
}
exports.findExternalPackageJsonPath = findExternalPackageJsonPath;
